Rohde & Schwarz AREG100A automotive radar echo generator RsAreg instrument driver.

Supported instruments: AREG

The package is hosted here: https://pypi.org/project/RsAreg/

Documentation: https://RsAreg.readthedocs.io/

Examples: https://github.com/Rohde-Schwarz/Examples/

----------------------------------------------------------------------------------

Release Notes:

Latest release notes summary: Fixed bug in 'base' interface (RsAreg.source.areGenerator.radar.base)

Version 4.80.70.15

- Fixed bug in 'base' interface (RsAreg.source.areGenerator.radar.base)

Version 4.80.70.13

- First release for FW 4.80.070
